@@ -12,18 +12,15 @@
 #
 #
 
-import re
-import os
+__version__ = "0.0.6"
 
+import os
 import json
 import psycopg2
-
 from tabulate import tabulate
-
+from ipykernel.kernelapp import IPKernelApp
 from ipykernel.kernelbase import Kernel
 
-__version__ = "0.0.4"
-
 DEBUG = 0
 
 
@@ -33,7 +30,6 @@ con = None
 def qry2df(qry, constr=None):
     try:
         df = []
-        row = []
         hdr = []
 
         log(str(type(constr)))
@@ -175,7 +171,4 @@ class SQLpKernel(Kernel):
         log("SHUTDOWN")
 
 
-from ipykernel.kernelapp import IPKernelApp
-from sqlp_kernel.kernel import SQLpKernel
-
 IPKernelApp.launch_instance(kernel_class=SQLpKernel)
